/* Damir Stijepic						*/
/* Johannes Gutenberg University, Mainz	*/
/* email: mail@damir.stijepic.com		*/
/* June 2019							*/

/* ################################################################################## */
/* ################################################################################## */

							/* MISCELLANEOUS */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ------------------------------- Miscellaneous ------------------------------------ */
/* ---------------------------------------------------------------------------------- */

#delimit;
clear all;
set scrollbufsize 2048000;
set more off;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------   END   -------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* ---------------------------------   Log File   ----------------------------------- */
/* ---------------------------------------------------------------------------------- */

capture log close damir;	

log using "${MY_OUT_TEXT_PATH}3_sipp_ms_variables_log"
	, name(damir) replace text;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------   END   -------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* --------------------------------   Load Data   ----------------------------------- */	
/* ---------------------------------------------------------------------------------- */

/* --------------------------------  SIPP Data   ------------------------------------ */

use "${MY_OUT_PATH}2_sipp_ms_variableselection.dta", clear;

/* --------------------------------   CPI Data   ------------------------------------ */

gen cpi=1.569 if year==1996;
replace cpi=1.605 if year==1997;
replace cpi=1.630 if year==1998;
replace cpi=1.666 if year==1999;
replace cpi=1.722 if year==2000;

sort id period;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------   END   -------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

						/* DEMOGRAPHICS AND OTHER VARIABLES*/
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ------------------------------ DEMOGRAPHICS   ------------------------------------ */
/* ---------------------------------------------------------------------------------- */

/* ----------------------------------- Gender --------------------------------------- */

gen female=1 if esex==2;
replace female=0 if esex==1;

/* ------------------------------------ Race ---------------------------------------- */

rename erace race;

/* ------------------------------------- Age ---------------------------------------- */

gen age=year-tbyear if year>=tbyear;
						
/* --------------------------------- Marital Status --------------------------------- */

gen mstatus=.;
label value mstatus mstatus;

replace mstatus=1  if ems==1;
replace mstatus=2  if ems==2;
replace mstatus=3  if ems>=3 & ems<=5;
replace mstatus=4  if ems==6;

label define mstatus 	1 "[1] married, spouse present" 
						2 "[2] married, spouse absent" 
						3 "[3] widowed, divorced, separated"
						4 "[4] never married"
						;
							
/* ------------------------------------- Children ----------------------------------- */

gen children=.;
label value children children;

replace children=1  if rfnkids==0;
replace children=2  if rfnkids==1;
replace children=3  if rfnkids==2;
replace children=4  if rfnkids==3;
replace children=5  if rfnkids>=4 & rfnkids~=.;

label define children 	1 "[1] 0" 
						2 "[2] 1" 
						3 "[3] 2"
						4 "[4] 3"
						5 "[5] 4+"
						;
						
/* ------------------------------------- Born in US --------------------------------- */

gen us_born=1 if ebrstate>=1 & ebrstate<=56;
replace us_born=0 if ebrstate>=555 & ebrstate<=571;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------   END   -------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* ------------------------------ OTHER VARIABLES   --------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ------------------------------------- State -------------------------------------- */

rename tfipsst state; 

replace state=62 if state==38 | state==46 | state==56;
replace state=61 if state==50 | state==23;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------   END   -------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

								/* EMPLOYMENT VARIABLES */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ---------------------   OCCUPATIONS AND INDUSTRIES   ----------------------------- */
/* ---------------------------------------------------------------------------------- */

/* -----------------------------   Consistent Classifications  ---------------------- */

foreach var of varlist eeno1 tjbocc1 eocctim1 ejbind1 
						eeno2 tjbocc2 ejbind2{;
replace `var'=. if `var'==-1;
};

foreach var of varlist tjbocc1 tjbocc2 {;
replace `var'=. if `var'==905;
};

foreach var of varlist ejbind1 ejbind2{;
replace `var'=. if `var'==991;
};

rename tjbocc1 occ1;
rename eocctim1 occtim1;
rename ejbind1 ind1;
rename tjbocc2 occ2;
rename ejbind2 ind2;
					
foreach var in occ ind {;
gen `var'=`var'1 if estlemp1==1;
replace `var'=`var'2 if estlemp2==1 & `var'==.;
};

/* -------------------------   2-Digits Classifications   --------------------------- */


foreach var in occ {;
gen `var'1990_digits2=.;
local numl=1;
quietly foreach numh of numlist 
22 23 43 44 64 69 84 95 98 113 155 166 174 178 183 203 213 223 226 
243 253 263 275 283 303 308 313 316 325 337 345 354 359 375 379
403 413 433 445 448 456 473 477 485 494 503 505 523
535 553 563 613 628 634 656 666 675 686 689 694 703 719 726 734 738
753 783 796 803 823 828 843 866 875 900
{;
replace `var'1990_digits2=`numl' if `var'>=`numl' & `var'<`numh';
local numl=`numh';
};
};


foreach var in ind {;
gen `var'1990_digits2=.;
local numl=1;
quietly foreach numh of numlist 
40 60 100 230 400 440 450 500 540 580 700 721 761 800 812 900 940 990
{;
replace `var'1990_digits2=`numl' if `var'>=`numl' & `var'<`numh';
local numl=`numh';
};
};

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------   END   -------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* -------------------------- Employment Status ------------------------------------- */
/* ---------------------------------------------------------------------------------- */

gen emp=.;
label value emp emp;

replace emp=1 if rmesr>=1 & rmesr<=5;
replace emp=2 if rmesr>=6 & rmesr<=7;
replace emp=3 if rmesr>=8 & rmesr<=8;

label define emp	1 "[1] with job" 
					2 "[2] no job, on layoff/looking for work" 
					3 "[3] no job, not on layoff/looking for work" 
					;
					
/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ----------------------------------------------------------------------------------- */
/* ------------------------------ Employer Size -------------------------------------- */
/* ----------------------------------------------------------------------------------- */

foreach var in tempall tempsiz eemploc eunion ecntrc epayhr rpyper tsjdate {;
gen `var'=`var'1 if estlemp1==1;
replace `var'=`var'2 if estlemp2==1 & `var'==.;
replace `var'=. if `var'<1;
};
 
/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */					
/* ----------------------------------- Fulltime ------------------------------------- */
/* ---------------------------------------------------------------------------------- */	

foreach var in ejbhrs {;
gen `var'=`var'1 if estlemp1==1;
replace `var'=`var'2 if estlemp2==1 & `var'==.;
};

gen full=1 if ejbhrs>=35 & ejbhrs~=.;
replace full=0 if ejbhrs>0 & ejbhrs<35;	

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */	
/* --------------------------- Class of Worker -------------------------------------- */
/* ---------------------------------------------------------------------------------- */

foreach var in eclwrk {;
gen `var'=`var'1 if estlemp1==1;
replace `var'=`var'2 if estlemp2==1 & `var'==.;
};


gen emp_class=.;
label value emp_class emp_class;

replace emp_class=1 if eclwrk>=1 & eclwrk<=1;
replace emp_class=2 if eclwrk>=2 & eclwrk<=6;

label define emp_class	1 "[1] private for profit" 
						2 "[2] other" 
						;
						
/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

							/* SAMPLE SELECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* --------------------------------   Sample 1   ------------------------------------ */
/* ---------------------------------------------------------------------------------- */

gen sample1=1 if
/* ----------------------------------- Age ------------------------------------------ */
	age>=25 & age<55
/* ----------------------------- Private for Profit --------------------------------- */
&	emp_class==1
/* --------------------- Pot. Work Preventing Disability ---------------------------- */
& 	edisabl==2
/* --------------------------------- Fulltime --------------------------------------- */
&	full==1
/* --------------------------------- Gender ----------------------------------------- */
&	female==0
/* ----------------------------------- Race ----------------------------------------- */
&	race==1
/* ------------------------------- Born in US --------------------------------------- */
&	us_born==1
/* ------------------------------------- Industry ----------------------------------- */
&	ind<900
/* ------------------------------------- Occupation --------------------------------- */
&	occ<900
;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

							/* WAGES AND JOB CHANGES*/
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */						
/* ------------------------------ Hourly Wages -------------------------------------- */
/* ---------------------------------------------------------------------------------- */

foreach var in tpmsum {;
gen `var'=`var'1 if estlemp1==1;
replace `var'=`var'2 if estlemp2==1 & `var'==.;
};

gen hr_wage=(tpmsum/(ejbhrs*rmwkwjb))  if tpmsum>0 & ejbhrs>0 & rmwkwjb>0;
gen loghr_wage=log(hr_wage);

quietly levelsof period, local(levels);
foreach num of local levels {;
clear results;
sum loghr_wage  if period==`num' & sample1==1, detail;
replace loghr_wage=r(p99) if period==`num' & loghr_wage>r(p99) & !missing(loghr_wage);
replace loghr_wage=r(p1) if period==`num' & loghr_wage<r(p1);
};

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* ------------------------------ Job Changes --------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ------------------------------ All Transitions ----------------------------------- */

gen transition=.;
label value transition transition;

* same employer;
replace transition=100 if eeno1==F4.eeno1 & eeno1~=. & F4.eeno1~=.
					&	estlemp1==1 & F4.estlemp1==1;
replace transition=100 if eeno2==F4.eeno1 & eeno2~=. & F4.eeno1~=.
					&	estlemp1==2 & estlemp2==1 & F4.estlemp1==1;
					
* same employer and same occupation;					
replace transition=110 if eeno1==F4.eeno1 & eeno1~=. & F4.eeno1~=.
					&	estlemp1==1 & F4.estlemp1==1
					& 	occ1==F4.occ1 & occ1~=. & F4.occ1~=.;
replace transition=110 if eeno2==F4.eeno1 & eeno2~=. & F4.eeno1~=.
					&	estlemp1==2 & estlemp2==1 & F4.estlemp1==1
					& 	occ2==F4.occ1 & occ2~=. & F4.occ1~=.;	
					
* same employer and change in occupation;					
replace transition=120 if eeno1==F4.eeno1 & eeno1~=. & F4.eeno1~=.
					&	estlemp1==1 & F4.estlemp1==1
					& 	occ1~=F4.occ1 & occ1~=. & F4.occ1~=.;
replace transition=120 if eeno2==F4.eeno1 & eeno2~=. & F4.eeno1~=.
					&	estlemp1==2 & estlemp2==1 & F4.estlemp1==1
					& 	occ2~=F4.occ1 & occ2~=. & F4.occ1~=.;	
					
* employer--employer transition;	
replace transition=200 if eeno1~=F4.eeno1 & eeno1~=. & F4.eeno1~=.
					&	estlemp1==1 & F4.estlemp1==1;
replace transition=200 if eeno2~=F4.eeno1 & eeno2~=. & F4.eeno1~=.
					&	estlemp1==2 & estlemp2==1 & F4.estlemp1==1;					
					
* unemployment;
replace transition=300 if (estlemp1==1 | estlemp2==1) &  F4.emp==2;

* not in labor force;		
replace transition=400 if (estlemp1==1 | estlemp2==1) &  F4.emp==3;		

* impute miscoded transitions;
gen occ_flag=0;
replace occ_flag=1 if swave==2 & month==7 & transition==120 & F4.ajbocc1>0;
replace occ_flag=1 if swave==2 & month==7 & transition==120 & tsjdate~=F4.tsjdate;
replace occ_flag=1 if swave==2 & month==7 & transition==120 & ind~=F4.ind;
replace occ_flag=1 if swave==2 & month==7 & transition==120 & eunion==F4.eunion & ecntrc==F4.ecntrc  & epayhr==F4.epayhr & rpyper==F4.rpyper;
replace occ_flag=1 if swave==2 & month==7 & transition==120 & tpmsum>=F4.tpmsum*0.95 & tpmsum<=F4.tpmsum*1.05
																				 & ejbhrs>=F4.ejbhrs*0.95 & ejbhrs<=F4.ejbhrs*1.05;
replace transition=110 if occ_flag==1;

label define transition 100 "[100] same employer" 
						110 "[110] same employer (same occ)"
						120 "[120] same employer (new occ)"
						200 "[200] employer-employer" 
						300 "[300] unemp"
						400 "[400] NILF"
						;					
				
/* ----------------------------------- Job Changes   -------------------------------- */

gen job_change=0 if transition==100 | transition==110 | transition==120;
replace job_change=1 if transition==300;
replace job_change=2 if transition==200;
replace job_change=3 if transition==400;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

								/* EDUCATION AND SKILLS */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* --------------------------- Educational Attainment ------------------------------- */
/* ---------------------------------------------------------------------------------- */

gen educ=.;
label value educ educ; 

replace educ=1 if eeducate>=31 & eeducate<=38;
replace educ=2 if eeducate>=39 & eeducate<=39;
replace educ=3 if eeducate>=40 & eeducate<=43;
replace educ=4 if eeducate>=44 & eeducate<=44;
replace educ=5 if eeducate>=45 & eeducate<=47;

label define educ 	1 "[1] LTHS" 
					2 "[2] HS" 
					3 "[3] Some college" 
					4 "[4] College" 
					5 "[5] Advanced"
					;
					
gen college=0 if educ>=1 & educ<=2;
replace college=1 if educ>=3 & educ<=5;
					
/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */					
/* ---------------------------------- Versatility ----------------------------------- */
/* ---------------------------------------------------------------------------------- */

gen no_courses=0;
replace no_courses=. if ecourse1==. | ecourse2==. | ecourse3==. | ecourse4==. |
	 ecourse5==. | ecourse6==. |  ecourse7==.;
replace no_courses=. if ecourse1==-1 | ecourse2==-1 | ecourse3==-1 | ecourse4==-1 |
	 ecourse5==-1 | ecourse6==-1 |  ecourse7==-1;

foreach num of numlist 1(1)7 {;
replace no_courses=no_courses+1 if ecourse`num'==1;
replace ecourse`num'=0 if ecourse`num'==2;
replace ecourse`num'=. if ecourse`num'==-1;
};

gen versatile=1 if  no_courses>=4 & no_courses<=7;
replace versatile=0 if no_courses>=0 & no_courses<=3;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* -------------------------- Potential Experience ---------------------------------- */
/* ---------------------------------------------------------------------------------- */
 
gen pot_exp=.;
foreach var of varlist tadvncyr tbachyr tassocyr tvocyr tlastcol thsyr tlstschl {;
 replace `var'=. if `var'==-1;
 replace pot_exp=year-`var' if year>=`var' & pot_exp==. & `var'>0;
};
 
/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

						/* ADDITIONAL GENERATED VARIABLES */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ---------------------------- Occupational Tenure --------------------------------- */
/* ---------------------------------------------------------------------------------- */

reg occtim1 c.loghr_wage i.educ  c.age c.age#c.age c.pot_exp i.tempsiz
			i.mstatus i.children i.ind1990_digits2 i.occ1990_digits2 i.state i.versatile
			i.ecourse7 i.ecourse6 i.ecourse5 i.ecourse4
			i.ecourse3 i.ecourse2 i.ecourse1
			if sample1==1 & swave==1;
predict occtim_help;
replace occtim_help=0 if occtim_help<0;
 

* no occupational changes;
replace occtim1=L4.occtim1+4 if occtim1==. & occ1990_digits2==L4.occ1990_digits2 & occ1990_digits2~=. & L4.occ1990_digits2~=.;		
replace occtim1=L4.occtim1+4 if occtim1==. & L4.occ_flag==1;
replace occtim1=L4.occtim1+4 if occtim1==. & occ1990_digits2==L4.occ1990_digits2 & occ1990_digits2~=. & L4.occ1990_digits2~=.;
		

quietly {;		
* occupational changes;
gen occtim1_ext=occtim1;
replace occtim1_ext=occtim_help if occtim1_ext==. & occ1990_digits2~=. & swave==1;
replace occtim1_ext=L4.occtim1_ext+4 if occtim1_ext==. 
		& occ1990_digits2==L4.occ1990_digits2 & occ1990_digits2~=. & L4.occ1990_digits2~=.;
foreach num2 of numlist 2(1)12 {;

local num_help=(`num2'-1)*4;
foreach num of numlist 4(4)`num_help' {;
replace occtim1_ext=L`num'.occtim1_ext+2 if occtim1_ext==. & L`num'.occtim1_ext~=.
		& occ1990_digits2==L`num'.occ1990_digits2 & occ1990_digits2~=. & L`num'.occ1990_digits2~=.
		& swave==`num2';
replace occtim1_ext=L4.occtim1_ext+4 if occtim1_ext==. 
		& occ1990_digits2==L4.occ1990_digits2 & occ1990_digits2~=. & L4.occ1990_digits2~=.;
};


replace occtim1_ext=2 if occtim1_ext==. 
		& occ1990_digits2~=L4.occ1990_digits2 & occ1990_digits2~=. & L4.occ1990_digits2~=. & swave==`num2';		
replace occtim1_ext=occtim_help if occtim1_ext==. 
		& occ1990_digits2~=. & swave==`num2';
replace occtim1_ext=L4.occtim1_ext+4 if occtim1_ext==. 
		& occ1990_digits2==L4.occ1990_digits2 & occ1990_digits2~=. & L4.occ1990_digits2~=.;
};
};

gen occ_year1=occtim1/12;
gen occ_year1_ext=occtim1_ext/12;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */ 
/* --------------------------------- Match Quality ---------------------------------- */
/* ---------------------------------------------------------------------------------- */ 

* Regression;
clear results;
reg loghr_wage 
		c.cpi i.occ1990_digits2 
		(c.pot_exp c.pot_exp#c.pot_exp i.educ)#ibn.occ1990_digits2
		if sample1==1;
predict wage_res,  residual;

* Match Quality;
quietly levelsof occ1990_digits2, local(levels);
gen rel_wage_res=.;
quietly foreach num of local levels {;
clear results;
sum wage_res
		if occ1990_digits2==`num' & sample1==1, detail;					
replace rel_wage_res=3 
	if wage_res>=r(p50) & wage_res<r(p75) & occ1990_digits2==`num';
replace rel_wage_res=2 
	if wage_res~=. & wage_res>=r(p90) & occ1990_digits2==`num';
replace rel_wage_res=1 
	if wage_res<r(p90) & wage_res>=r(p75) & occ1990_digits2==`num';
replace rel_wage_res=4
	if wage_res>r(p25) & wage_res<r(p50) & occ1990_digits2==`num';
replace rel_wage_res=5 
	if wage_res>r(p10) & wage_res<=r(p25) & occ1990_digits2==`num';
replace rel_wage_res=6 
	if wage_res<=r(p10) & occ1990_digits2==`num';
};
drop wage_res;


/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */			
			
/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

								/* CLOSING FILE */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ----------------------------------- Save Dataset  -------------------------------- */
/* ---------------------------------------------------------------------------------- */

compress;
save  "${MY_OUT_PATH}3_sipp_ms_variables.dta", replace;

/* ---------------------------------------------------------------------------------- */
/* -------------------------------------- END --------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* --------------------------------------- Log  ------------------------------------- */
/* ---------------------------------------------------------------------------------- */

log close damir;

/* ---------------------------------------------------------------------------------- */
/* -------------------------------------- END --------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */
