/* Damir Stijepic						*/
/* Johannes Gutenberg University, Mainz	*/
/* email: mail@damir.stijepic.com		*/
/* June 2019							*/

/* ################################################################################## */
/* ################################################################################## */

							/* MISCELLANEOUS */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ------------------------------- Miscellaneous ------------------------------------ */
/* ---------------------------------------------------------------------------------- */

#delimit;
clear all;
set scrollbufsize 2048000;
set more off;
set maxiter 30;
set matsize 11000;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* ---------------------------------   Log File   ----------------------------------- */
/* ---------------------------------------------------------------------------------- */

capture log close damir;	

log using "${MY_OUT_TEXT_PATH}4_sipp_regressions_log"
	, name(damir) replace text;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* --------------------------------   Load Data   ----------------------------------- */	
/* ---------------------------------------------------------------------------------- */

use if sample1==1 using "${MY_OUT_PATH}3_sipp_ms_variables.dta", clear;
gen educ2=educ;
replace educ=1 if educ2==2;
replace educ=2 if educ2==1;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

							    /* BASICS */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* -----------------------------   CONTROL VARIABLES   ------------------------------ */
/* ---------------------------------------------------------------------------------- */

/* --------------------------   Mobility Regressions   ------------------------------ */


local control3 	i.educ
				c.pot_exp c.occ_year1_ext 
				i1.versatile 
				c.loghr_wage
				i.rel_wage_res i.tempsiz
				i.year i.month i.state i.occ1990_digits2 i.ind1990_digits2
				i.ecourse7 i.ecourse6 i.ecourse5 i.ecourse4
				i.ecourse3 i.ecourse2 i.ecourse1
				i.mstatus i.children c.age c.age#c.age
				;	
				
local control2 	i.educ
				c.pot_exp c.occ_year1_ext 
				i1.versatile 
				i.year i.month
				i.mstatus i.children c.age c.age#c.age
				;			

local control1 	i.educ
				c.pot_exp c.occ_year1_ext 
				i.year i.month
				i.mstatus i.children c.age c.age#c.age
				;			

local control0 	i.educ
				i.year i.month
				i.mstatus i.children c.age c.age#c.age
				;
						
/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* ------------------------------   SAMPLE SELECTION   ------------------------------ */
/* ---------------------------------------------------------------------------------- */

quietly reg job_change `control3' if sample1==1;

foreach var of varlist occ1990_digits2 {;
replace sample1=0 if ! e(sample);
egen tag=tag(id `var') if e(sample);
bys `var': egen obs=total(tag) if e(sample);
tab obs;
replace sample1=0 if obs<10 | obs==.;
drop obs tag;
};

* drop islands (Hawaii);
replace sample1=0 if state==15;

sort id period;

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

									/* REGRESSIONS */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ---------------------------------   BASELINE   ----------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------   REGRESSION  ---------------------------------- */

foreach num of numlist 0 1 2 3 {;
clear results;
mlogit job_change `control`num'' if sample1==1
								, vce(cluster id) difficult;
foreach var in i2.educ i3.educ i4.educ i5.educ c.pot_exp 
			c.occ_year1_ext i1.versatile c.loghr_wage
			i2.rel_wage_res i3.rel_wage_res i4.rel_wage_res
			i5.rel_wage_res i6.rel_wage_res 
			i2.tempsiz i3.tempsiz {;
capture {;
noisily lincom [2]`var';
noisily lincom [1]`var';
noisily lincom [2]`var'-[1]`var';
};
};
};													

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* ---------------------------------   HETEROGENEITY   ------------------------------ */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------   REGRESSION  ---------------------------------- */

foreach var2 in i1.versatile c.pot_exp c.occ_year1_ext {;
local not `var2';
local control4: list control3 - not;
clear results;
mlogit job_change i.educ#`var2' `control4' if sample1==1
								, vce(cluster id) difficult;
foreach var in i2.educ i1.educ i3.educ i4.educ i5.educ {;
capture {;
noisily lincom [2]`var'#`var2'-[1]`var'#`var2';
};
};
};											

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

									/* STATISTICS */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ---------------------------   STASTICS BY EDUCATION   ---------------------------- */
/* ---------------------------------------------------------------------------------- */

replace educ=educ2;

/* ---------------------------------------   Statistics   --------------------------- */

gen rel_wage_res2=1 if rel_wage_res==1 | rel_wage_res==2;
replace rel_wage_res2=2 if rel_wage_res==3 | rel_wage_res==4;
replace rel_wage_res2=3 if rel_wage_res==5 | rel_wage_res==6;

gen versatile2=versatile*100;
gen college2=college*100;

foreach var of varlist rel_wage_res2 tempsiz educ job_change no_courses versatile {;
tab `var', gen(`var'_d);
};

foreach var of varlist rel_wage_res2_d* tempsiz_d* educ_d* job_change_d* no_courses_d* versatile_d*{;
replace `var'=`var'*100;
};

foreach var of varlist age college2 no_courses versatile2 pot_exp occ_year1_ext   
		rel_wage_res2_d* hr_wage tempsiz_d* {;
clear results;		
reg `var' if sample1==1;		
};

foreach num of numlist 1(1)5 {;
clear results;		
reg educ_d`num' if sample1==1;
foreach var of varlist age college2 no_courses versatile2 pot_exp occ_year1_ext   
		rel_wage_res2_d* hr_wage tempsiz_d* {;
clear results;		
reg `var' if sample1==1 & educ==`num';		
};
};

foreach num of numlist 1(1)2 {;
clear results;		
reg versatile_d`num' if sample1==1;
foreach var of varlist age college2 no_courses versatile2 pot_exp occ_year1_ext   
		rel_wage_res2_d* hr_wage tempsiz_d* {;
clear results;		
reg `var' if sample1==1 & versatile_d`num'==100;		
};
};


/* --------------------------------------   Shares   -------------------------------- */

foreach var of varlist job_change_d* {;
clear results;
reg `var' if sample1==1;
foreach num of numlist 1(1)5 {;
clear results;
reg `var' if educ==`num' & sample1==1;
};
foreach num of numlist 0(1)1 {;
clear results;
reg `var' if versatile==`num' & sample1==1;
};
};

/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* -------------------------------------- FIGURES   --------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* --------------------------------   Course Choices   ------------------------------ */

tab no_courses if sample1==1;

graph hbar (mean) no_courses_d1 no_courses_d2 no_courses_d3 no_courses_d4 
	no_courses_d5 no_courses_d6 no_courses_d7 no_courses_d8 if sample1==1, 
	bar(1, fcolor(gs8) lcolor(black)) bar(2, fcolor(gs8) lcolor(black))
	bar(3, fcolor(gs8) lcolor(black)) bar(4, fcolor(gs8) lcolor(black))
	bar(5, fcolor(gs8) lcolor(black)) bar(6, fcolor(gs8) lcolor(black))
	bar(7, fcolor(gs8) lcolor(black)) bar(8, fcolor(gs8) lcolor(black))
	ytitle(percent)  /*title("Seperations") percentages*/ outergap(10) bargap(10)
	legend(off) showyvars yvaroptions(
	relabel(1 "none" 2 "1 course" 3 "2 courses" 
	4 "3 courses" 5 "4 courses" 6 "5 courses"
	7 "6 courses" 8 "7 courses"))
	scheme(s1color) ylabel(0(5)25) yscale(range(0 25));
graph save "${MY_OUT_TEXT_PATH}histo_no_courses.gph", replace;
graph export "${MY_OUT_TEXT_PATH}histo_no_courses.eps", replace;

foreach num of numlist 1(1)7 {;
tab ecourse`num' if sample1==1, nolabel;
gen ecourse`num'p=100*ecourse`num';
};

graph hbar (mean) ecourse1p ecourse2p ecourse3p ecourse4p 
	ecourse5p ecourse6p ecourse7p if sample1==1, 
	bar(1, fcolor(gs8) lcolor(black)) bar(2, fcolor(gs8) lcolor(black))
	bar(3, fcolor(gs8) lcolor(black)) bar(4, fcolor(gs8) lcolor(black))
	bar(5, fcolor(gs8) lcolor(black)) bar(6, fcolor(gs8) lcolor(black))
	bar(7, fcolor(gs8) lcolor(black))
	ytitle(percent)  /*title("Seperations") percentages*/ outergap(10) bargap(10)
	legend(off) showyvars yvaroptions(
	relabel(1 "advanced math" 2 "advanced sciences" 3 "English literature" 
	4 "foreign language" 5 "home economics" 6 "business courses"
	7 "fine arts"))
	scheme(s1color) ylabel(0(10)80) yscale(range(0 80));
graph save "${MY_OUT_TEXT_PATH}histo_courses.gph", replace;
graph export "${MY_OUT_TEXT_PATH}histo_courses.eps", replace;

/* ----------------------------------   OTHER   -------------------------------- */

sum occ_year1 if sample1==1 & swave==1, detail;
sum occ_year1_ext if sample1==1, detail;

hist occ_year1_ext if sample1==1, percent width(1) start(0)
ytitle("percent") ylabel(0(2)10) yscale(range(0 11))
xtitle("") xlabel(0(5)40) xscale(range(0 40))
xtitle("occupational tenure in years")
scheme(s1color) color(black) fintensity(inten40);	
graph save "${MY_OUT_TEXT_PATH}histo_occ_tenure.gph", replace;
graph export "${MY_OUT_TEXT_PATH}histo_occ_tenure.eps", replace;	

hist pot_exp if sample1==1, percent width(1) start(0)
ytitle("percent") ylabel(0(2)10) yscale(range(0 11))
xtitle("") xlabel(0(5)40) xscale(range(0 40))
xtitle("general experience in years")
scheme(s1color) color(black) fintensity(inten40);	
graph save "${MY_OUT_TEXT_PATH}histo_exp.gph", replace;
graph export "${MY_OUT_TEXT_PATH}histo_exp.eps", replace;	


/* ---------------------------------------------------------------------------------- */
/* -----------------------------------------   END   -------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */

/* ################################################################################## */
/* ################################################################################## */

								/* CLOSING FILE */
					
/* ################################################################################## */
/* ################################################################################## */

/* ---------------------------------------------------------------------------------- */
/* ----------------------------------- Save Dataset  -------------------------------- */
/* ---------------------------------------------------------------------------------- */

compress;
save  "${MY_OUT_PATH}4_sipp_regressions.dta", replace;

/* ---------------------------------------------------------------------------------- */
/* -------------------------------------- END --------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ---------------------------------------------------------------------------------- */
/* --------------------------------------- Log  ------------------------------------- */
/* ---------------------------------------------------------------------------------- */

log close damir;

/* ---------------------------------------------------------------------------------- */
/* -------------------------------------- END --------------------------------------- */
/* ---------------------------------------------------------------------------------- */

/* ################################################################################## */
/* ################################################################################## */

								/* END OF SECTION */
					
/* ################################################################################## */
/* ################################################################################## */
